import{d as y,r as i,K as x,b,c as g,B as m,x as c,N as v,A as B,z as w,q as D}from"./registerWidgets.29e41a54.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="cdefdad2-9c7f-4030-a5ca-50b8e1dfc4fd",t._sentryDebugIdIdentifier="sentry-dbid-cdefdad2-9c7f-4030-a5ca-50b8e1dfc4fd")}catch{}})();const k={class:"text"},I=y({__name:"Tooltip",props:{text:{type:String,required:!0},left:{type:Number},top:{type:Number},fixed:{type:Boolean,default:!1}},setup(t){const e=t,s=i(Date.now()),f=()=>{s.value=Date.now()},n=i(null),p=()=>{var r,d,l;const o=(r=n.value)==null?void 0:r.getBoundingClientRect();if(!o)return{};const{x:a,y:_}=o;return s.value,{position:"fixed",top:`${_+((d=e.top)!=null?d:0)}px`,left:`${a+((l=e.left)!=null?l:0)}px`}},u=x(()=>{var o;return e.fixed?p():{left:`${(o=e.left)!=null?o:-14}px`,...e.top?{top:`${e.top}px`}:{}}});return(o,a)=>(b(),g("div",{ref_key:"tooltipBox",ref:n,class:"tooltip-box",onMouseenter:f},[m(o.$slots,"default",{},void 0,!0),c("div",{class:"tooltip",style:B(w(u))},[c("span",k,v(t.text),1)],4)],544))}});const $=D(I,[["__scopeId","data-v-74636348"]]);export{$ as T};
//# sourceMappingURL=Tooltip.1c0158ea.js.map
